/* ********************************************************************* */
/*    Filename: BASIC.INC               #include file of declarations    */
/*                  Lights! Cameras! Objects! FXs!                       */
/*    Declarations of standardized cameras, lights, shapes, etc.         */
/*    for use in any scene script.                                       */
/*    All definitions refer to test object at <0 0 0> on plane <0 1 0>   */
/*    BASIC.INC                                     AUG-OCT 96  Ver. 1.0 */
/* ********************************************************************* */
/* ********************************************************************* */

#include "colors.inc"                  // standard colors
#include "shapes.inc"                  // standard shapes
#include "textures.inc"                // standard textures

/* ********************************************************************* */
/*                           DECLARE LIGHTS                              */
/* ********************************************************************* */

// DEFINE LIGHT SOURCE  *****  way up high and really way in *****

#declare FloodRear =
light_source
    { < -1500 4000 7000 >
      color White
     }  //end light FloodRear
/* ********************************** */

// DEFINE LIGHT SOURCE  *****  *****

#declare FloodSouth =
light_source {
   < 300 300 -2000 >
   color White
             }  //end light SouthFlood
/* ********************************** */

// DEFINE SPOT LIGHTS  *****   *****

#declare SpotLeft1 =
light_source
   { < -50 5 5 >                       // from -x +y +z toward...
     color White
     spotlight
     point_at < 0.0  5.0  0.0 >        // center of obj < 0 5 0 >
     tightness 45
     radius 25
     falloff 45
   }  //end SpotLeft1
/* ********************************** */

#declare SpotRight1 =
light_source
   { < 50 5 5 >                        // from +x +y +z toward...
     color White
     spotlight
     point_at < 0.0 5.0 0.0 >          // center of obj < 0 5 0 >
     tightness 45
     radius 25
     falloff 45
    }  //end SpotRight1
/* ********************************** */

#declare SpotLeft2 =
light_source
    { < -50 10 -20 >                    // from -x +y -z toward...
      color White
      spotlight
      point_at < 0.0 5.0 0.0 >         // center of object < 0 5 0 >
      tightness 75
      radius 10
      falloff 15
    }  //end of SpotLeft2
/* ********************************** */

#declare SpotRight2 =
light_source
    { < 50 10 -20 >                    // from +x +y -z toward...
      color White
      spotlight
      point_at < 0.0 5.0 0.0 >         // center of obj < 0 5 0 >
      tightness 75
      radius 10
      falloff 15
    }  //end of SpotRight2

/* ********************************************************************* */
/*                           DECLARE CAMERAS                             */
/* ********************************************************************* */

// STANDARD TEST VIEW POINTS of object at world center < 0 5 0 >

#declare South1 =
camera {
  location  <  0.0   20.0  -50.0 >     // due South of center
  direction <  0.0    0.0    2.0 >
  up        <  0.0    1.0    0.0 >
  right     <  1.33   0.0    0.0 >
  look_at   <  0.0    5.0    0.0 >     // world center 5.0 above floor
       }  //end of camera South1
/* ********************************** */

#declare East1 =
camera {
  location  < 50.0   20.0   0.0 >      // due East of center...
  direction <  0.0    0.0   2.0 >
  up        <  0.0    1.0   0.0 >
  right     <  1.33   0.0   0.0 >
  look_at   <  0.0    5.0   0.0 >      // world center 5.0 above floor
       }  //end of camera East1
/* ********************************** */

#declare North1 =
camera {
   location  < 0.0  20.0  50.0 >       // due North of center
   direction < 0.0   0.0   2.0 >
   up        < 0.0   1.0   0.0 >
   right     < 1.33  0.0   0.0 >
   look_at   < 0.0   5.0   0.0 >       // world center 5.0 above floor
       }  //end of camera North1
/* ********************************** */

#declare West1 =
camera {
   location  < -50.0  20.0  0.0 >      // due West of center...
   direction <   0.0   0.0  2.0 >
   up        <   0.0   1.0  0.0 >
   right     <   1.33  0.0  0.0 >
   look_at   <   0.0   5.0  0.0 >     // world center 5.0 above floor
         }  //end of camera West1
/* ********************************** */

#declare SouthWest1 =
camera {
  location  < -25.0  20.0  -25.0 >     // SW and above...
  direction <   0.0   0.0    2.0 >
  up        <   0.0   1.0    0.0 >
  right     <   1.33  0.0    0.0 >
  look_at   <   0.0   5.0    0.0 >     // world center 5.0 above floor
       }  //end of camera SouthWest1
/* ********************************** */

#declare SouthEast1 =
camera {
  location  < 25.0  20.0  -25.0 >      // SE and above...
  direction <  0.0   0.0    2.0 >
  up        <  0.0   1.0    0.0 >
  right     <  1.33  0.0    0.0 >
  look_at   <  0.0   5.0    0.0 >      // world center 5.0 above floor
       }  //end of camera SouthEast1
/* ********************************** */

#declare NorthWest1 =
camera {
  location  < -25.0  20.0  25.0 >      // NW and above...
  direction <   0.0   0.0   2.0 >
  up        <   0.0   1.0   0.0 >
  right     <   1.33  0.0   0.0 >
  look_at   <   0.0   5.0   0.0 >      // world center 5.0 above floor
       }  //end of camera NorthWest1
/* ********************************** */

#declare NorthEast1 =
camera {
  location  < 25.0  20.0  25.0 >       // NE and above...
  direction <  0.0   0.0   2.0 >
  up        <  0.0   1.0   0.0 >
  right     < 1.33   0.0   0.0 >
  look_at   <  0.0   5.0   0.0 >       // world center 5.0 above floor
       }  //end of camera NorthEast1
/* ********************************** */

#declare SouthWest2 =
camera {
  location  < -50.0  25.0  -50.0 >     // farther SW2
  direction <   0.0   0.0    2.0 >
  up        <   0.0   1.0    0.0 >
  right     <   1.33  0.0    0.0 >
  look_at   <   0.0   5.0    0.0 >     // world center 5.0 above floor
       }  //end of camera SouthWest2
/* ********************************** */

#declare SouthEast2 =
camera {
  location  < 50.0  25.0  -50.0 >      // farther SE and above...
  direction <  0.0   0.0    2.0 >
  up        <  0.0   1.0    0.0 >
  right     <  1.33  0.0    0.0 >
  look_at   <  0.0   5.0    0.0 >      // world center 5.0 above floor
       }  //end of camera SouthEast2
/* ********************************** */

#declare NorthWest2 =
camera {
  location  < -50.0  25.0  50.0 >      // farther NW and above...
  direction <   0.0   0.0   2.0 >
  up        <   0.0   1.0   0.0 >
  right     <   1.33  0.0   0.0 >
  look_at   <   0.0   5.0   0.0 >      // world center 5.0 above floor
       }  //end of camera NorthWest2
/* ********************************** */

#declare NorthEast2 =
camera {
  location  < 50.0  25.0  50.0 >       // farther NE
  direction <  0.0   0.0   2.0 >
  up        <  0.0   1.0   0.0 >
  right     < 1.33   0.0   0.0 >
  look_at   <  0.0   5.0   0.0 >       // world center 5.0 above floor
       }  //end of camera NorthEast2
/* ********************************** */

#declare OverLow =
camera {
  location  <   0.0  100.0  -1.0 >     // low high, over world center
  direction <   0.0    0.0   2.0 >
  up        <   0.0    1.0   0.0 >
  right     <   1.33   0.0   0.0 >
  look_at   <   0.0    0.0   0.0 >     // world center
       }  //end of camera OverLow

/* ********************************** */

#declare OverMed =
camera {
  location  <   0.0  300.0  -1.0 >     // medium high, over world center
  direction <   0.0    0.0   2.0 >
  up        <   0.0    1.0   0.0 >
  right     <   1.33   0.0   0.0 >
  look_at   <   0.0    0.0   0.0 >     // world center
       }  //end of camera OverMed

/* ********************************** */

#declare OverHigh =
camera {
  location  <   0.0  650.0  -1.0 >     // way up high, over world center
  direction <   0.0    0.0   2.0 >
  up        <   0.0    1.0   0.0 >
  right     <   1.33   0.0   0.0 >
  look_at   <   0.0    0.0   0.0 >     // world center
       }  //end of camera OverHigh

/* ********************************************************************* */
/*                           DECLARE TEXTURES                            */
/* ********************************************************************* */

#declare Black_Tex =
texture { color Black
        } // end Black Texture

/* ********************************************************************* */

#declare Yellow_Tex =
texture { color Yellow
        } // end Yellow Texture

/* ********************************************************************* */

#declare Red_Tex =
texture { color Red
        } // end texture Red

/* ********************************************************************* */

#declare Blue_Tex =
texture { color Blue
        } // end texture Blue

/* ********************************************************************* */

#declare Green_Tex =
texture { color Green
        } // end texture Green

/* ********************************************************************* */

#declare White_Tex =
texture { color White
        } // end texture White

/* ********************************************************************* */

#declare Gray75_Tex =
texture { color Gray75
        } // end texture White

/* ********************************************************************* */

#declare Chex_Tex =
texture {                              // black & white tiles
   checker  color Black  color White
   scale < 10 10 10 >
        } // end texture B & W checks

/* ********************************************************************* */
/*                           DECLARE OBJECTS                             */
/* ********************************************************************* */
/* *****     DECLARE  WALLS     ***** */

// These next three are finite planes.
#declare Square_X =  union {    /* Scale-able plane in x */
   triangle { < 0  1 -1> < 0 -1  1> < 0  1  1>  }
   triangle { < 0  1 -1> < 0 -1  1> < 0 -1 -1>  }
                           }
/* ********************************** */

#declare Square_Y =  union {    /* Scale-able plane in y */
   triangle { <-1 0 1>   < 1 0 -1>  <1 0 1>  }
   triangle { <-1 0  1>  < 1 0 -1>  <-1 0 -1>}
                           }
/* ********************************** */

#declare Square_Z =  union {    /* Scale-able plane in z */
   triangle { <-1 1 0.0> <1 -1 0.0> <-1 -1 0.0> }
   triangle { <-1 1 0.0> <1 -1 0.0> <1 1 0.0>   }
                           }
/* ********************************** */

// DECLARE GENERIC WALL PANELS  *****  *****

#declare This_Wall_1 =
object {
   union { Square_Z }
       }  //end of obj Wall 1
/* ********************************** */

#declare This_Wall_2 =
object {
   union { Square_Y }
       }  //end of obj Wall 2
/* ********************************** */

#declare This_Wall_3 =
object {
   union { Square_X }
       }  //end of obj Wall 3

/* ********************************************************************* */
/* *****   DECLARE  SPHERES    ***** */

#declare Planet_Blank =                // specify texture in script file
object {
  sphere { < 0.0 0.0 0.0 > 1.0 }
       }  //end obj Planet_Blank

/* ********************************** */

#declare Planet_Mirror =
object {
  sphere { <0.0 0.0 0.0> 1.0 }
  texture {                            // specify any or no texture in script
              ambient 0.0              // this is a shiny mirror surface
              diffuse 0.0
              reflection 1.0
              brilliance 10.0
              specular 1.0
              roughness 0.001
          }  // end of texture
       }  // end of object Planet_Mirror

/* ********************************************************************* */
/* *****     DECLARE  BOXES     ***** */

#declare Box_Plain =
object {
  intersection { Cube }
       }  // end object Box Plain

/* ********************************************************************* */
/* DECLARE  Generic PILLARS  *****  ***** */

#declare Pillar_A =
object {
  intersection { Disk_Y }
  scale < 1 5 1 >
  color Blue
       }  // end object

/* ********************************** */

#declare Pillar_B =
object {
  intersection { Disk_X }
  scale < 5 1 1 >
  color SeaGreen
       }  // end object

/* ********************************** */

#declare Pillar_C =
object {
  intersection { Disk_Z }
  scale < 1 1 5 >
  color IndianRed
       }  // end object
/* ********************************** */

// DEFINE Test Object     *****     *****

#declare TestShape =
composite {
   object { box { UnitBox
                  scale < 1 1 1 > }
               texture { White_Marble }
               color Blue
          } // end obj Box
   object { Planet_Blank
               scale < 1 1 1 >
               texture { Red_Marble }
               translate < 0 2 0 >
               color Green
          } // end obj Sphere
          }  // end Test Shape

/* ********************************************************************* */
//                             Floor Definitions                         //
/* ********************************************************************* */

#declare Test_Floor =
object { plane { < 0 1 0 > 0 }
         texture { Chex_Tex }          // or any other quick/simple texture
         scale < 2 2 2 >
         color White
       }  //end of obj Test Floor

/* ********************************** */

// DEFINE  Plain Plank FLOOR  *****  blue, gray planks  *****

#declare Plank_Floor =
object { plane { < 0 1 0 > 0.0 }
         texture { gradient < 1 0 0 >
                   color_map {
                     [0.0   0.25  color Gray25  color Gray25]
                     [0.25  0.50  color Gray35  color Gray40]
                     [0.50  0.75  color Gray85  color Gray90]
                     [0.75  1.00  color Gray90  color Gray95]
                             }  //end of colormap
                   scale < 1.45 5.0 1.0 >  // narrow y stripes
                   ambient 0.1
                   diffuse 0.2
                   reflection 0.2
                 }  //end of texture
         color LightGray
       }  //end of object Plank Floor

/* ********************************************************************* */

#declare Grnt20 = texture {            // White Marble, gray feather veins
   granite
   turbulence 0.0
   color_map {
      [0.0  0.3  color Mica   color White]
      [0.2  0.4  color White  color White]
      [0.4  0.6  color White  color White]
      [0.6  1.0  color White  color White]
             }  // end color map
   0.02
                          }  // end texture

/* ********************************************************************* */

// DECLARE FLOOR 13  *****  pale grey, blue-striped stone  *****

#declare Floor13 =
object {
   plane { <0 1 0 > 0 }
   texture { Grnt20
                scale < 2 2 1 >
                turbulence 1.4
                reflection 0.2
                specular 0.2
           }  //end tex
   scale < 3 3 3 >
   color LightGray
       }  //end obj Floor13

/* ********************************************************************* */

// DEFINE Temple, Checker Floor   *****   bounded ver. of above

#declare Floor13_B =
object {
   plane { <0 1 0 > 0 }
   texture { Grnt20
                scale < 3 2 1 >
                turbulence 0.020
                rotate < 20 0 0 >
                reflection 0.100
                specular 0.100
           }  //end tex
   scale < 3 3 3 >
   color LightGray
   bounded_by { box { UnitBox
                      scale < 200 0.5 200 > }
              }  // end bounding
       }  //end obj Floor13_B

/* ********************************************************************* */
// **********     A 3-dimensional grid of colored spheres     ********** //
/* ********************************************************************* */

#declare Grid_Mark =

object { sphere { < 0 0 0 > 1 }
         scale < 1 1 1 >
       } //end obj  GridMark

/* ********************************************************************* */

// DEFINE a co-axial grid of marks on the floor

#declare Grid_Zero =                   // x & y axis and +-50 unit marks
composite {

   object { Grid_Mark
            texture { White_Tex }
            translate <  0 0 0 >       // center of world
            scale < 2 2 2 >
            color White }

// **********   **********             +x axis
   object { Grid_Mark
            texture { Red_Tex }
            translate < 10 0 0 >
            color Red }
   object { Grid_Mark
            texture { Red_Tex }
            translate < 20 0 0 >
            color Red }
   object { Grid_Mark
            texture { Red_Tex }
            translate < 30 0 0 >
            color Red }
   object { Grid_Mark
            texture { Red_Tex }
            translate < 40 0 0 >
            color Red }
   object { Grid_Mark
            texture { Yellow_Tex }
            translate < 50 0 0 >
            color Yellow }
   object { Grid_Mark
            texture { Red_Tex }
            translate < 60 0 0 >
            color Red }
   object { Grid_Mark
            texture { Red_Tex }
            translate < 70 0 0 >
            color Red }
   object { Grid_Mark
            texture { Red_Tex }
            translate < 80 0 0 >
            color Red }
   object { Grid_Mark
            texture { Red_Tex }
            translate < 90 0 0 >
            color Red }
   object { Grid_Mark
            texture { Green_Tex }
            translate < 100 0 0 >
            color Green }
   object { Grid_Mark
            translate < 110 0 0 >
            color Red }
   object { Grid_Mark
            translate < 120 0 0 >
            color Red }
   object { Grid_Mark
            translate < 130 0 0 >
            color Red }
   object { Grid_Mark
            translate < 140 0 0 >
            color Red }
   object { Grid_Mark
            translate < 150 0 0 >
            color Yellow }
   object { Grid_Mark
            translate < 160 0 0 >
            color Red }
   object { Grid_Mark
            translate < 170 0 0 >
            color Red }
   object { Grid_Mark
            translate < 180 0 0 >
            color Red }
   object { Grid_Mark
            translate < 190 0 0 >
            color Red }
   object { Grid_Mark
            translate < 200 0 0 >
            color Blue }

// **********   **********             -x axis
   object { Grid_Mark
            texture { Red_Tex }
            translate < -10 0 0 >
            color Red }
   object { Grid_Mark
            texture { Red_Tex }
            translate < -20 0 0 >
            color Red }
   object { Grid_Mark
            texture { Red_Tex }
            translate < -30 0 0 >
            color Red }
   object { Grid_Mark
            texture { Red_Tex }
            translate < -40 0 0 >
            color Red }
   object { Grid_Mark
            texture { Yellow_Tex }
            translate < -50 0 0 >
            color Yellow }
   object { Grid_Mark
            texture { Red_Tex }
            translate < -60 0 0 >
            color Red }
   object { Grid_Mark
            texture { Red_Tex }
            translate < -70 0 0 >
            color Red }
   object { Grid_Mark
            texture { Red_Tex }
            translate < -80 0 0 >
            color Red }
   object { Grid_Mark
            texture { Red_Tex }
            translate < -90 0 0 >
            color Red }
   object { Grid_Mark
            texture { Green_Tex }
            translate < -100 0 0 >
            color Green }
   object { Grid_Mark
            translate < -110 0 0 >
            color Red }
   object { Grid_Mark
            translate < -120 0 0 >
            color Red }
   object { Grid_Mark
            translate < -130 0 0 >
            color Red }
   object { Grid_Mark
            translate < -140 0 0 >
            color Red }
   object { Grid_Mark
            translate < -150 0 0 >
            color Yellow }
   object { Grid_Mark
            translate < -200 0 0 >
            color Blue }

// **********   **********             +z axis
   object { Grid_Mark
            texture { Red_Tex }
            translate < 0 0 10 >
            color Red }
   object { Grid_Mark
            texture { Red_Tex }
            translate < 0 0 20 >
            color Red }
   object { Grid_Mark
            texture { Red_Tex }
            translate < 0 0 30 >
            color Red }
   object { Grid_Mark
            texture { Red_Tex }
            translate < 0 0 40 >
            color Red }
   object { Grid_Mark
            texture { Yellow_Tex }
            translate < 0 0 50 >
            color Yellow }
   object { Grid_Mark
            texture { Red_Tex }
            translate < 0 0 60 >
            color Red }
   object { Grid_Mark
            texture { Red_Tex }
            translate < 0 0 70 >
            color Red }
   object { Grid_Mark
            texture { Red_Tex }
            translate < 0 0 80 >
            color Red }
   object { Grid_Mark
            texture { Red_Tex }
            translate < 0 0 90 >
            color Red }
   object { Grid_Mark
            texture { Green_Tex }
            translate < 0 0 100 >
            color Green }
   object { Grid_Mark
            translate < 0 0 110 >
            color Red }
   object { Grid_Mark
            translate < 0 0 120 >
            color Red }
   object { Grid_Mark
            translate < 0 0 130 >
            color Red }
   object { Grid_Mark
            translate < 0 0 140 >
            color Red }
   object { Grid_Mark
            translate < 0 0 150 >
            color Yellow }
   object { Grid_Mark
            translate < 0 0 200 >
            color Blue }

// **********   **********             -z axis
   object { Grid_Mark
            texture { Red_Tex }
            translate < 0 0 -10 >
            color Red }
   object { Grid_Mark
            texture { Red_Tex }
            translate < 0 0 -20 >
            color Red }
   object { Grid_Mark
            texture { Red_Tex }
            translate < 0 0 -30 >
            color Red }
   object { Grid_Mark
            texture { Red_Tex }
            translate < 0 0 -40 >
            color Red }
   object { Grid_Mark
            texture { Yellow_Tex }
            translate < 0 0 -50 >
            color Yellow }
   object { Grid_Mark
            texture { Red_Tex }
            translate < 0 0 -60 >
            color Red }
   object { Grid_Mark
            texture { Red_Tex }
            translate < 0 0 -70 >
            color Red }
   object { Grid_Mark
            texture { Red_Tex }
            translate < 0 0 -80 >
            color Red }
   object { Grid_Mark
            texture { Red_Tex }
            translate < 0 0 -90 >
            color Red }
   object { Grid_Mark
            texture { Green_Tex }
            translate < 0 0 -100 >
            color Green }
   object { Grid_Mark
            translate < 0 0 -150 >
            color Yellow }
   object { Grid_Mark
            translate < 0 0 -200 >
            color Blue }

// **********   **********             -X -Z Quadrant   *** THE 50's
   object { Grid_Mark
            translate < -50 0 -50 >
            color Violet }
   object { Grid_Mark
            translate < -50 0 -100 >
            color Yellow }
   object { Grid_Mark
            translate < -50 0 -150 >
            color Yellow }
   object { Grid_Mark
            translate < -50 0 -200 >
            color Blue }
   object { Grid_Mark
            translate < -100 0 -50 >
            color Yellow }
   object { Grid_Mark
            translate < -100 0 -100 >
            color Yellow }
   object { Grid_Mark
            translate < -100 0 -150 >
            color Yellow }
   object { Grid_Mark
            translate < -100 0 -200 >
            color Blue }

// **********   **********             -x +z Quadrant
   object { Grid_Mark
            translate < -50 0 50 >
            color Violet }
   object { Grid_Mark
            translate < -50 0 100 >
            color Yellow }
   object { Grid_Mark
            translate < -50 0 150 >
            color Yellow }
   object { Grid_Mark
            translate < -50 0 200 >
            color Blue }
   object { Grid_Mark
            translate < -100 0 50 >
            color Yellow }
   object { Grid_Mark
            translate < -100 0 100 >
            color Yellow }
   object { Grid_Mark
            translate < -100 0 150 >
            color Yellow }
   object { Grid_Mark
            translate < -100 0 200 >
            color Blue }

// **********   **********             +x -z Quadrant
   object { Grid_Mark
            translate < 50 0 -50 >
            color Violet }
   object { Grid_Mark
            translate < 50 0 -100 >
            color Yellow }
   object { Grid_Mark
            translate < 50 0 -150 >
            color Yellow }
   object { Grid_Mark
            translate < 50 0 -200 >
            color Blue }
   object { Grid_Mark
            translate < 100 0 -50 >
            color Yellow }
   object { Grid_Mark
            translate < 100 0 -100 >
            color Yellow }
   object { Grid_Mark
            translate < 100 0 -150 >
            color Yellow }
   object { Grid_Mark
            translate < 100 0 -200 >
            color Blue }

// **********   **********             +x +z Quadrant
   object { Grid_Mark
            translate < 50 0 50 >
            color Violet }
   object { Grid_Mark
            translate < 50 0 100 >
            color Yellow }
   object { Grid_Mark
            translate < 50 0 150 >
            color Yellow }
   object { Grid_Mark
            translate < 50 0 200 >
            color Blue }
   object { Grid_Mark
            translate < 100 0 50 >
            color Yellow }
   object { Grid_Mark
            translate < 100 0 100 >
            color Yellow }
   object { Grid_Mark
            translate < 100 0 150 >
            color Yellow }
   object { Grid_Mark
            translate < 100 0 200 >
            color Blue }
          }  // end composite Grid Zero


// **********   **********

#declare Grid_Plus =
composite {                            // ***** Quadrant I  +20x
   object { Grid_Mark
            translate < 20 0 20 >
            color Red }
   object { Grid_Mark
            translate < 20 0 40 >
            color Red }
   object { Grid_Mark
            translate < 20 0 60 >
            color Red }
   object { Grid_Mark
            translate < 20 0 80 >
            color Red }
   object { Grid_Mark
            translate < 20 0 100 >
            color Yellow }
   object { Grid_Mark
            translate < 20 0 150 >
            color Yellow }
   object { Grid_Mark
            translate < 20 0 200 >
            color Blue }

// **********   **********             +40x axis
   object { Grid_Mark
            translate < 40 0 20 >
            color Red }
   object { Grid_Mark
            translate < 40 0 40 >
            color Red }
   object { Grid_Mark
            translate < 40 0 60 >
            color Red }
   object { Grid_Mark
            translate < 40 0 80 >
            color Red }
   object { Grid_Mark
            translate < 40 0 100 >
            color Yellow }
   object { Grid_Mark
            translate < 40 0 150 >
            color Yellow }
   object { Grid_Mark
            translate < 40 0 200 >
            color Blue }

// **********   **********             +60x axis
   object { Grid_Mark
            translate < 60 0 20 >
            color Red }
   object { Grid_Mark
            translate < 60 0 40 >
            color Red }
   object { Grid_Mark
            translate < 60 0 60 >
            color Red }
   object { Grid_Mark
            translate < 60 0 80 >
            color Red }
   object { Grid_Mark
            translate < 60 0 100 >
            color Yellow }
   object { Grid_Mark
            translate < 60 0 150 >
            color Yellow }
   object { Grid_Mark
            translate < 60 0 200 >
            color Blue }

// **********   **********             +80x axis
   object { Grid_Mark
            translate < 80 0 20 >
            color Red }
   object { Grid_Mark
            translate < 80 0 40 >
            color Red }
   object { Grid_Mark
            translate < 80 0 60 >
            color Red }
   object { Grid_Mark
            translate < 80 0 80 >
            color Red }
   object { Grid_Mark
            translate < 80 0 100 >
            color Yellow }
   object { Grid_Mark
            translate < 80 0 150 >
            color Yellow }
   object { Grid_Mark
            translate < 80 0 200 >
            color Blue }

// **********   **********             +100x axis
   object { Grid_Mark
            translate < 100 0 20 >
            color Green }
   object { Grid_Mark
            translate < 100 0 40 >
            color Green }
   object { Grid_Mark
            translate < 100 0 50 >
            color Yellow }
   object { Grid_Mark
            translate < 100 0 60 >
            color Green }
   object { Grid_Mark
            translate < 100 0 80 >
            color Green }
   object { Grid_Mark
            translate < 100 0 100 >
            color Yellow }
   object { Grid_Mark
            translate < 100 0 150 >
            color Yellow }
   object { Grid_Mark
            translate < 100 0 200 >
            color Blue }

// **********   **********             +150 z axis
   object { Grid_Mark
            translate < 0 0 150 >
            color Yellow }
   object { Grid_Mark
            translate <  50 0 150 >
            color Yellow }
   object { Grid_Mark
            translate <  100 0 150 >
            color Yellow }
   object { Grid_Mark
            translate < 150 0 150 >
            color Yellow }
   object { Grid_Mark
            translate < 200 0 150 >
            color Blue }

// **********   **********             +200 z axis
    object { Grid_Mark
             translate < 0 0 200 >
             color Blue }
    object { Grid_Mark
             translate < 50 0 200 >
             color Blue }
    object { Grid_Mark
             translate < 100 0 200 >
             color Blue }
    object { Grid_Mark
             translate < 150 0 200 >
             color Blue }
    object { Grid_Mark
             translate < 200 0 200 >
             color Blue }
           }  // end composite Grid Plus


// *********   **********

#declare Grid_Up =                     // ***** +y axis from <0 0 0>
composite {
   object { Grid_Mark
            translate < 0 10 0 >
            color Magenta }
   object { Grid_Mark
            translate < 0 20 0 >
            color Magenta }
   object { Grid_Mark
            translate < 0 30 0 >
            color Magenta }
   object { Grid_Mark
            translate < 0 40 0 >
            color Magenta }
   object { Grid_Mark
            translate < 0 50 0 >
            color Yellow }
   object { Grid_Mark
            translate < 0 60 0 >
            color Magenta }
   object { Grid_Mark
            translate < 0 70 0 >
            color Magenta }
   object { Grid_Mark
            translate < 0 80 0 >
            color Magenta }
   object { Grid_Mark
            translate < 0 90 0 >
            color Magenta }
   object { Grid_Mark
            translate < 0 100 0 >
            color Yellow }
   object { Grid_Mark
            translate < 0 110 0 >
            color Green }
   object { Grid_Mark
            translate < 0 120 0 >
            color Magenta }
   object { Grid_Mark
            translate < 0 130 0 >
            color Magenta }
   object { Grid_Mark
            translate < 0 140 0 >
            color Magenta }
   object { Grid_Mark
            translate < 0 150 0 >
            color Yellow }
   object { Grid_Mark
            translate < 0 200 0 >
            color Blue }

// *********   **********              vertical ( -y ) axis at 0 0 0
   object { Grid_Mark
            translate < 0 -10 0 >
            color Magenta }
   object { Grid_Mark
            translate < 0 -20 0 >
            color Magenta }
   object { Grid_Mark
            translate < 0 -30 0 >
            color Magenta }
   object { Grid_Mark
            translate < 0 -40 0 >
            color Magenta }
   object { Grid_Mark
            translate < 0 -50 0 >
            color Yellow }
   object { Grid_Mark
            translate < 0 -60 0 >
            color Magenta }
   object { Grid_Mark
            translate < 0 -70 0 >
            color Magenta }
   object { Grid_Mark
            translate < 0 -80 0 >
            color Magenta }
   object { Grid_Mark
            translate < 0 -90 0 >
            color Magenta }
   object { Grid_Mark
            translate < 0 -100 0 >
            color Green }
   object { Grid_Mark
            translate < 0 -150 0 >
            color Magenta }
   object { Grid_Mark
            translate < 0 -200 0 >
            color Blue }
          }  // end composite Grid Up

/* ********************************************************************* */
/* END OF  BASIC.INC  FILE                                    ********** */
/* ********************************************************************* */
