/* ********************************************************************* */
//   Filename: NW1.POV                                                   //
//   Michael Brendan Hurley for ShadowDancer Enterprizes, LTD.           //
//   View of Floor NW +1 in ChekFloor1 Scene       Aug-Oct 1996 Ver 2.0  //
//   Annotated for use as a tutorial .POV file                           //
/* ********************************************************************* */

/* ********************************************************************* */
//                           Global Definitions                          //
/* ********************************************************************* */

#include "basic.inc"                   // Lights Cameras Simple objects
#include "temple.inc"                  // Complex objects and effects

/* ********************************************************************* */
/* ********************************************************************* */

// DEFINE DEFAULTS

#default { texture { ambient 0.4 } }   // ambient light
max_trace_level 8                      // see Manual p.98
/* ********************************** */

//DEFINE SKY  *****   fuzzy strings of color   *****

object { sphere { < 0 0 0 > 35000 }    // a distant sphere for the sky
         texture { Sky_Agate                // a blue/gray texture
            scale < 6000 90000 6000 >       // enlarge texture
            rotate < 55 0 0 >               // spin texture on x axis
            ambient 0.3                     // a faint glow to everything
            diffuse 0.0                     // no shiny-ness
                 }  //end texture
         texture { Sky_Agate2               // this red texture overlaid
            scale < 5800 90000 5700 >       // enlarged by this much
            rotate < 51 0 0 >               // spun differently on x axis
            ambient 0.3                     // same
            diffuse 0.0                     // same
                 }  //end texture
         color White                   // low resolution display color
       }  //end object Sky
/* ********************************** */

// DECLARE TEST CAMERA  *****  set location and look_at  *****

#declare TestView =
camera {
  location  < -30  30  -100 >           //  NW+1
  direction <   0.0   0.0   2.0 >
  up        <   0.0   1.0   0.0 >
  right     <   1.33  0.0   0.0 >
  look_at   <   5.0   5.0   0.0 >      // center of world
       }  //end of camera Test View

/* ********************************************************************* */
/* ********************************************************************* */

// DEFINE SCENE  *****  A Checkered Pattern of Floors        *****
//               *****  The Scene on Floor NW +1             *****

// LIGHTS!                        ***** DEFINE LIGHT SOURCES

//                                ***** Universal To All Scenes
object { light_source { FloodRear } }  // high rear flood light
object { light_source { FloodSouth } } // low front flood light

//                                ***** Specific To Floors
//object { light_source { NESpot } }     // high checker flood light
object { light_source { NWSpot } }     // high checker flood light
//object { light_source { SESpot } }     // high checker flood light
//object { light_source { SWSpot } }     // high checker flood light


// CAMERA!                        ***** POSITION CAMERA

camera { TestView                      // Variable with each view
         translate < -400 0 400 > }    // offset to NW +1 Floor
//camera { OverHigh }                    // < 0 650 -1 > look at < 0 0 0 >
//camera { OverMed }                     // < 0 300 -1 >
//camera { OverLow }                     // < 0 100 -1 >

//camera { South1 }                      // <   0 20 -50 >
//camera { West1 }                       // < -50 20   0 >
//camera { North1 }                      // <   0 20  50 >
//camera { East1 }                       // <  50 20   0 >

//camera { SouthWest1 }                  // < -25 20 -25 >
//camera { SouthWest2 }                  // < -50 20 -50 >
//camera { NorthWest1 }                  // < -25 20  25 >
//camera { NorthWest2 }                  // < -50 20  50 >

//camera { SouthEast1 }                  // < 25 20 -25 >
//camera { SouthEast2 }                  // < 50 20 -50 >
//camera { NorthEast1 }                  // < 25 20  25 >
//camera { NorthEast2 }                  // < 50 20  50 >

// ********************************************************************* //
// ACTION!     ***** Position objects                                    //
// ********************************************************************* //

//  *****     DISPLAY  NW +1  FLOOR SCENE    *****
//  *****     all non-visible Floors deleted

#declare ChekFloor1 =                  // Checker pattern of Floors
composite {

   composite {                         // Central Floor
      object { Floor13_B }
             }                         // end of Central floor

   composite {                         // start of NE+1  *****
      object { Floor13_B
                 translate < 400 0 400 > }
             } // end composite             end of NE +1   **********

/* ********************************************************************* */

   composite {                         // start of NW+1    **********

      object { Floor13_B
               translate < -400 0 400 > }
      composite { Circle_A                  // ring of pillars, globes
                  scale < 2.2 2.2 2.2 >
                  translate < -400 0 400 >
                }  // end of Object Circle A
      composite { Column_1                  // lamp post
                  translate < -300 0 300 > }     // SE
      composite { Column_1
                  translate < -500 0 300 > }     // SW
      composite { Column_1
                  translate < -500 0 500 > }     // NW
      composite { Column_1
                  translate < -300 0 500 > }     // NE

      composite { Column_2                  // regular post
                  translate < -360 0 430 > }     // EAST
      composite { Column_2
                  translate < -360 0 370 > }
      composite { Column_2
                  translate < -370 0 440 > }     // NORTH
      composite { Column_2
                  translate < -430 0 440 > }
      composite { Column_2
                  translate < -440 0 430 > }     // WEST
      composite { Column_2
                  translate < -440 0 370 > }
      composite { Column_2
                  translate < -370 0 360 > }     // SOUTH
      composite { Column_2
                  translate < -430 0 360 > }

      object { Box_Plain
               scale < 8.5 2 2 >
               rotate < 0 -45 0 >
               translate < -435 21 435 >    // NE
               color Violet
             }  // end obj Box
      object { Box_Plain
               scale < 8.5 2 2 >
               rotate < 0 -45 0 >
               translate < -365 21 365 >    // SW
               color Violet
             } // end box
      object { Box_Plain
               scale < 8.5 2 2 >
               rotate < 0 45 0 >
               translate < -365 21 435 >    // NW
               color Violet
             }  // end obj Box
      object { Box_Plain
               scale < 8.5 2 2 >
               rotate < 0 45 0 >
               translate < -435 21 365 >    // SW
               color Violet
             }  // end obj Box

             }  // end of composite              NW +1     ***********

/* ********************************************************************* */

   object { Floor13_B                       // N +2
              translate <    0 0  800 > }
   object { Floor13_B                       // S +2
              translate <    0 0 -800 > }
   object { Floor13_B                       // NE +2
              translate <  800 0  800 > }
   object { Floor13_B                       // NW +2
              translate < -800 0  800 > }
   object { Floor13_B                       // NNW +3
              translate <  -400 0  1200 > }
   object { Floor13_B                       // NNE +3
              translate <   400 0  1200 > }

   }  // end composite ChekFloor1                        **********

/* ********************************************************************* */
// **********   MAIN LINE OF SCRIPT FILE    **********                   //
/* ********************************************************************* */

composite { ChekFloor1 }               // Checker board of Floor13b's

/* ********************************************************************* */
/* END OF   NW +1 Floor Scene  FILE           ************************** */
/* ********************************************************************* */
