/* ********************************************************************* */
//   Filename: SE1.POV                                                   //
//   Current Test: Floor SE +1  The HoloDeck, the Grids,                 //
/* ********************************************************************* */

/* ********************************************************************* */
//                           Global Definitions                          //
/* ********************************************************************* */

#include "basic.inc"                   // Lights Cameras Simple objects
#include "temple.inc"                  // Complex objects and effects

/* ********************************************************************* */
/* ********************************************************************* */

// DEFINE DEFAULTS

#default { texture { ambient 0.3 } }   // ambient light
/* ********************************** */

//DEFINE SKY  ***** *****
/*
object { sphere { < 0 0 0 > 80000 }
         texture { Blue_Sky            // big puffy white/gray clouds
            scale < 7000 2000 4000 >
            turbulence 0.25
            ambient 0.5
            diffuse 0.0
                 }  //end texture
         color White                   // low resolution display color
       }  //end object Sky
*/

/* ********************************************************************* */
/* ********************************************************************* */

// DECLARE TEST CAMERA  *****  set location and look_at  *****

#declare TestView =
camera {
//   location  < -100 25 -300 >          // master view
//   location  < 0 300 -10 >             // way above <0 0 0>
   location  < -95 75 95 >             // med SW of <0 0 0>
   direction < 0.0   0.0  2.0 >
   up        < 0.0   1.0  0.0 >
   right     < 1.33  0.0  0.0 >
//   look_at   < 0.0 25.0 0.0 >         // master view
  look_at   < 0 20 0 >
       }  //end of camera Test View

/* ********************************************************************* */

// DEFINE  Tube Sculpture  *****   *****

#declare Tubes =
composite {
object { Pillar_A
           texture { Yellow_Tex }
           scale < 2 2 2 >             // tube 2x20x2 units +-y
           translate < 420 10 -420 >
       } // end obj Pillar A

object { Pillar_B
           texture { Yellow_Tex }
           scale < 2 2 2 >             // tube 20x2x2 units +-x
           translate < 410 20 -420 >
       } // end obj Pillar B

object { Pillar_C
           texture { Yellow_Tex }
           scale < 2 2 2 >             // tube 2x2x20 units +-z
           translate < 400 20 -410 >
       } // end obj Pillar C

object { Pillar_A
           texture { Yellow_Tex }
           scale < 2 2 2 >             // tube 2x20x2 units +-y
           translate < 400 30 -400 >
       } // end obj Pillar A

object { Pillar_B
           texture { Yellow_Tex }
           scale < 4 2 2 >             // tube 40x2x2 units +-x
           translate < 420 40 -400 >
       } // end obj Pillar B

object { Pillar_C
           texture { Yellow_Tex }
           scale < 2 2 4 >             // tube 2x2x40 units +-z
           translate < 440 40 -420 >
       } // end obj Pillar C

object { Pillar_A
           texture { Yellow_Tex }
           scale < 2 2 2 >             // tube 2x20x2 units +-y
           translate < 440 30 -440 >
       } // end obj Pillar A
          }  // end composite Tubes

/* ********************************************************************* */
/* ********************************************************************* */

// DEFINE SCENE  *****  TEST OF ASSORTED STANDARDIZED ELEMENTS    *****


// LIGHTS!                        ***** DEFINE LIGHT SOURCES
//                                ***** for all scenes
object { light_source { FloodRear } }  // high rear flood light
object { light_source { FloodSouth } } // low front flood light
object { light_source { FloodSE } }    // high checker flood light
object { light_source { FloodSW } }    // high checker flood light

//                                  ***** for other floors
object { light_source { SESpot } }     // on SE +1 center


// CAMERA!                        ***** POSITION CAMERA

camera { TestView translate < 400 0 -400 > }    // Variable with each view
//camera { OverHigh translate < 400 0 -400 >}                    // < 0 600 -1 > look at < 0 0 0 >
//camera { OverMed  translate < 400 0 -400 >}                     // < 0 300 -1 >
//camera { OverLow  translate < 400 0 -400 >}                     // < 0 100 -1 >

//camera { South1 }                      // <   0 20 -50 >
//camera { West1 }                       // < -50 20   0 >
//camera { North1 }                      // <   0 20  50 >
//camera { East1 }                       // <  50 20   0 >

//camera { SouthWest1 }                  // < -25 20 -25 >
//camera { SouthWest2 }                  // < -50 20 -50 >
//camera { NorthWest1 }                  // < -25 20  25 >
//camera { NorthWest2 }                  // < -50 20  50 >

//camera { SouthEast1 }                  // < 25 20 -25 >
//camera { SouthEast2 }                  // < 50 20 -50 >
//camera { NorthEast1 }                  // < 25 20  25 >
//camera { NorthEast2 }                  // < 50 20  50 >


// ACTION!                        ***** DESCRIBE ELEMENTS IN SCENE

composite { Grid_Zero                  // adjusted to SE1
            translate < 400 0 -400 > }

//  *********************************************************
//  *****     TEST  THIS  OBJECT: a Floor w/ a scene    *****

#declare ChekFloor1 =                  // Checker pattern of Floors
composite {
         //          *****   TEST FOR Floor SE +1    *****
   composite {                         // Central Floor
      object { Floor13_B }
             }  // end composite          Center Floor

   composite {                         // start of SE+1    **********
      object { Floor13_B
                 translate < 400 0 -400 > }

      composite { Tubes }





/*                                            // Poles on floor edges
      object { Center_Pole                  // east center
                 texture { Blood_Sky }
                 scale < 0.125 5 0.125 >
                 translate < 595 0 -400 >
             }  // end object
      object { Center_Pole                  // north center
                 texture { Blood_Sky }
                 scale < 0.125 5 0.125 >
                 translate < 400 0 -205 >
             }  // end object
      object { Center_Pole                  // west center
                 texture { Blood_Sky }
                 scale < 0.125 5 0.125 >
                 translate < 205 0 -400 >
             }  // end object
      object { Center_Pole                  // south center
                 texture { Blood_Sky }
                 scale < 0.125 5 0.125 >
                 translate < 400 0 -595 >
             }  // end object
      composite { HoloBox                   // the HoloDeck Room
                    translate < 400 0 -400 > }
*/

             }  // end composite          end of SE+1      **********
          }  // end composite ChekFloor1                          **********


// *****   TEST THIS COMPLEX OBJECT   *****

composite { ChekFloor1 }               // Checker board of Floor13b's

/* ********************************************************************* */

/*
composite { Grid_Up                    // SW corner
            translate < 200 0 -600 > }
composite { Grid_Up                    //   "        "
            translate < 300 0 -600 > }
composite { Grid_Up                    //   "        "
            translate < 500 0 -600 > }
composite { Grid_Up                    // SE corner
            translate < 600 0 -600 > }

composite { Grid_Up                    //   "        "
            translate < 200 0 -500 > }
composite { Grid_Up                    //   "        "
            translate < 300 0 -500 > }
composite { Grid_Up                    //   "        "
            translate < 400 0 -500 > }
composite { Grid_Up                    //   "        "
            translate < 500 0 -500 > }
composite { Grid_Up                    //   "        "
            translate < 600 0 -500 > }

composite { Grid_Up                    //   "        "
            translate < 300 0 -400 > }
composite { Grid_Up                    //   "        "
            translate < 400 0 -400 > }
composite { Grid_Up                    //   "        "
            translate < 500 0 -400 > }

composite { Grid_Up                    //   "        "
            translate < 200 0 -300 > }
composite { Grid_Up                    //   "        "
            translate < 300 0 -300 > }
composite { Grid_Up                    //   "        "
            translate < 400 0 -300 > }
composite { Grid_Up                    //   "        "
            translate < 500 0 -300 > }
composite { Grid_Up                    //   "        "
            translate < 600 0 -300 > }

composite { Grid_Up                    // NW corner
            translate < 200 0 -200 > }
composite { Grid_Up                    //   "        "
            translate < 300 0 -200 > }
composite { Grid_Up                    //   "        "
            translate < 500 0 -200 > }
composite { Grid_Up                    // NE corner
            translate < 600 0 -200 > }
*/

/* ********************************************************************* */
/* END OF   SW +1   FILE                      ************************** */
/* ********************************************************************* */
