/* ********************************************************************* */
//   Filename: SW1.POV                                                   //
//   Michael Brendan Hurley for ShadowDancer Enterprizes, LTD            //
//   Floor SW +1  Statue, Pool, Wall, Trees, Groves     Oct 1996 Ver 1.0 //
/* ********************************************************************* */

/* ********************************************************************* */
//                           Global Definitions                          //
/* ********************************************************************* */

#include "basic.inc"                   // Lights Cameras Simple objects
#include "temple.inc"                  // Complex objects and effects

/* ********************************************************************* */
/* ********************************************************************* */

// DEFINE DEFAULTS

#default { texture { ambient 0.4 } }   // ambient light
/* ********************************** */

//DEFINE SKY  *****   fuzzy strings of color   *****

object { sphere { < 0 0 0 > 150000 }   // a distant sphere for the sky
         texture { Sky_Agate              // this blue/gray texture
            scale < 3000 80000 6000 >       // enlarge texture
            rotate < 55 0 0 >               // spin texture on x axis
            ambient 0.5                     // a faint glow to everything
            diffuse 0.0                     // no shiny-ness
                 }  //end texture
         texture { Sky_Agate2             // this red texture overlaid
            scale < 2800 80000 5800 >       // enlarged by this much
            rotate < -50 0 0 >              // spun differently on x axis
            ambient 0.5                     // same
            diffuse 0.0                     // same
                 }  //end texture
         color White                   // low resolution display color
       }  //end object Sky

/* ********************************** */

// DECLARE TEST CAMERA  *****  set location and look_at  *****

#declare TestView =
camera {
  location  < -115  35  -120 >         // SW +1 master view
  direction < 0.0   0.0  2.0 >
  up        < 0.0   1.0  0.0 >
  right     < 1.33  0.0  0.0 >
  look_at   < 0.0   5.0  0.0 >         // world center < 0 0 0 >
       }  //end of camera Test View

/* ********************************************************************* */
/* ********************************************************************* */

// DEFINE SCENE  *****  A Checkered Pattern of Floors        *****
//               *****  The Scene on Floor SW +1             *****

// LIGHTS!                        ***** DEFINE LIGHT SOURCES
//                                ***** for all scenes
object { light_source { FloodRear } }  // high rear flood light
object { light_source { FloodSouth } } // low front flood light
object { light_source { FloodSE } }    // high checker flood light
object { light_source { FloodSW } }    // high checker flood light

//                                  ***** for other floors
object { light_source { SWSpot } }     // on SW +1 center


// CAMERA!                        ***** POSITION CAMERA

camera { TestView
         translate < -400 0 -400 > }   // move to look at SW1 center
//camera { OverHigh
//         translate <-400 0 -400 > }    // < 0 600 -1 > look at < 0 0 0 >
//camera { OverMed
//         translate < -400 0 -400 >}    // < 0 300 -1 >
//camera { OverLow
//         translate < -400 0 -400 > }   // < 0 100 -1 >

//camera { South1 }                      // <   0 20 -50 >
//camera { West1 }                       // < -50 20   0 >
//camera { North1 }                      // <   0 20  50 >
//camera { East1 }                       // <  50 20   0 >

//camera { SouthWest1 }                  // < -25 20 -25 >
//camera { SouthWest2 }                  // < -50 20 -50 >
//camera { NorthWest1 }                  // < -25 20  25 >
//camera { NorthWest2 }                  // < -50 20  50 >

//camera { SouthEast1 }                  // < 25 20 -25 >
//camera { SouthEast2 }                  // < 50 20 -50 >
//camera { NorthEast1 }                  // < 25 20  25 >
//camera { NorthEast2 }                  // < 50 20  50 >

// ********************************************************************* //
// ACTION!     ***** Position objects
// ********************************************************************* //

// ACTION!                        ***** DESCRIBE ELEMENTS IN SCENE


#declare ChekFloor1 =                  // Checker patern of Floors
composite {

   composite {                         // Central Floor
      object { Floor13_B }
             } // end composite        // end of Central floor

/* ********************************************************************* */


   composite {                         // start of SW +1   **********
      object { Floor13_B
               translate < -400 0 -400 > }
      composite { ShrineGrove
               translate < -400 0 -400 > }
             }  // end composite       end of SW +1        *********


/* ********************************************************************* */

   composite {                         // start of NE+1    **********
      object { Floor13_B
                 translate < 400 0 400 > }
             } // end composite           end of NE +1     **********

   composite {                         // start of SE+1    **********
      object { Floor13_B
               translate < 400 0 -400 > }
             }  // end composite          end of SE+1      **********

   composite {                         // start of NW+1    **********
      object { Floor13_B
               translate < -400 0 400 > }
             }  // end of composite              NW +1     **********

/* ********************************************************************* */

   object { Floor13_B                       // E +2
              translate <  800 0    0 > }
   object { Floor13_B                       // N +2
              translate <    0 0  800 > }
   object { Floor13_B                       // S +2
              translate <    0 0 -800 > }
   object { Floor13_B                       // W +2
              translate < -800 0    0 > }
   object { Floor13_B                       // NNE +3
              translate <  400 0 1200 > }
   object { Floor13_B                       // NE +3
              translate < 1200 0 1200 > }
   object { Floor13_B                       // NEE +3
              translate < 1200 0  400 > }

   }  // end composite ChekFloor1

/* ********************************************************************* */
// **********   MAIN LINE OF SCRIPT FILE    **********                   //
/* ********************************************************************* */

// *****   MAIN LINE OF SCRIPT FILE   *****

composite { ChekFloor1 }               // Checker board of Floor13b's

/* ********************************************************************* */
/* END OF   SW +1    FILE                     ************************** */
/* ********************************************************************* */
